@@ -414,7 +414,21 @@ Chunk::getJsonAtPosition(size_t position) {
                         bson_iter_overwrite_bool(&baz, metrics[i]->values[position]);
                         break;
                     case BSON_TYPE_UTF8:
-                        //bson_iter_overwrite(&baz, metrics[i]->values[position]);
+                    case  BSON_TYPE_EOD:
+                    case BSON_TYPE_DOCUMENT:
+                    case BSON_TYPE_ARRAY:
+                    case BSON_TYPE_DECIMAL128:
+                    case BSON_TYPE_MAXKEY:
+                    case BSON_TYPE_MINKEY :
+                    case BSON_TYPE_BINARY:
+                    case BSON_TYPE_UNDEFINED:
+                    case BSON_TYPE_OID:
+                    case BSON_TYPE_NULL:
+                    case BSON_TYPE_REGEX:
+                    case BSON_TYPE_TIMESTAMP:
+                    case BSON_TYPE_DBPOINTER:
+
+                    default:
                         break;
                 }
             }
