@@ -501,8 +501,8 @@ BOOST_AUTO_TEST_SUITE(ftdc_basic_suite)
 
         auto half_ts = (*ts)[ts->size()/2];
 
-        auto first_half  = parser->getMetric("start", Dataset::FIRST_TIMESTAMP, half_ts);
-        auto second_half = parser->getMetric("start", half_ts, Dataset::LAST_TIMESTAMP);
+        auto first_half  = parser->getMetric("start",INVALID_TIMESTAMP, half_ts);
+        auto second_half = parser->getMetric("start", half_ts,INVALID_TIMESTAMP);
         auto first_half_size = first_half->size();
         auto second_half_size = second_half->size();
 
@@ -624,7 +624,7 @@ BOOST_AUTO_TEST_SUITE(ftdc_basic_suite)
         auto pChunk = chunkVector[0];
 
         // We construct the metrics. These are name and first value only since deltas have not been read.
-        pChunk->miau();
+        pChunk->Consume();
     }
 
 
@@ -659,8 +659,8 @@ BOOST_AUTO_TEST_SUITE(ftdc_basic_suite)
 
         auto half_ts = (*ts)[ts->size()/2];
 
-        auto first_half  = parser->getMetric("start", Dataset::FIRST_TIMESTAMP, half_ts);
-        auto second_half = parser->getMetric("start", half_ts, Dataset::LAST_TIMESTAMP);
+        auto first_half  = parser->getMetric("start",INVALID_TIMESTAMP, half_ts);
+        auto second_half = parser->getMetric("start", half_ts, INVALID_TIMESTAMP);
         auto first_half_size = first_half->size();
         auto second_half_size = second_half->size();
 
@@ -732,7 +732,7 @@ BOOST_AUTO_TEST_SUITE(ftdc_basic_suite)
         BOOST_CHECK_EQUAL(status, 0);
 
         auto connCreated_ampersand = parser->getMetric("@serverStatus.connections.totalCreated");
-        auto connCreated_flag      = parser->getMetric("serverStatus.connections.totalCreated",  Dataset::INVALID_TIMESTAMP, Dataset::INVALID_TIMESTAMP, true);
+        auto connCreated_flag      = parser->getMetric("serverStatus.connections.totalCreated",  INVALID_TIMESTAMP,INVALID_TIMESTAMP, true);
         auto connCreated_raw       = parser->getMetric("serverStatus.connections.totalCreated");
 
         BOOST_CHECK_EQUAL(connCreated_ampersand->size(), connCreated_flag->size());
@@ -842,7 +842,7 @@ BOOST_AUTO_TEST_SUITE(ftdc_basic_suite)
 
         auto status = parser->parseFiles(&fileList, false, false, true);
 
-        std::vector<Dataset::MetricsPtr> metricList = parser->getMetric(ftdc_metric_keys);
+        auto metricList = parser->getMetric(ftdc_metric_keys);
 
         BOOST_CHECK_EQUAL(metricList.size(), ftdc_metric_keys.size());
 
@@ -981,8 +981,8 @@ BOOST_AUTO_TEST_SUITE(ftdc_basic_suite)
 
         //
         size_t stride = 0;
-        Dataset::MetricsPtr matrix = parser->getMetricMatrix(ftdc_metric_keys, &stride);
-        Dataset::MetricsPtr ts = parser->getMetric("start");
+        auto matrix = parser->getMetricMatrix(ftdc_metric_keys, &stride);
+        auto ts = parser->getMetric("start");
 
         auto msg = str( boost::format("Size is %1%") % matrix->size() );
         BOOST_TEST_MESSAGE(msg);
@@ -990,9 +990,21 @@ BOOST_AUTO_TEST_SUITE(ftdc_basic_suite)
         BOOST_CHECK_EQUAL( matrix->size(), ftdc_metric_keys.size()*ts->size());
     }
 
+    BOOST_AUTO_TEST_CASE(get_json) {
+        auto parser = new FTDCParser();
 
+        std::vector<std::string> fileList;
+        for (auto &&fileInPath: std::filesystem::directory_iterator(DATA_TEST_DIR))
+            fileList.push_back(fileInPath.path().string());
 
-    BOOST_AUTO_TEST_CASE(dump_json) {     //
+        auto status = parser->parseFiles(&fileList, false, false, false);
+        auto p = parser->getJsonAtPosition(1);
+
+        BOOST_TEST_MESSAGE(p);
+
+    }
+
+    BOOST_AUTO_TEST_CASE(dump_json_ts) {     //
         // Create parser
         auto parser = new FTDCParser();
 
@@ -1000,9 +1012,24 @@ BOOST_AUTO_TEST_SUITE(ftdc_basic_suite)
         for (auto &&fileInPath: std::filesystem::directory_iterator(DATA_TEST_DIR))
             fileList.push_back(fileInPath.path().string());
 
-        parser->dumpDocsAsJson(fileList[0], "output.json" );
+        const std::string s =  "./output_ts.json";
+        auto ret = parser->dumpDocsAsJsonTimestamps(fileList[0], s, INVALID_TIMESTAMP, INVALID_TIMESTAMP );
 
+        BOOST_CHECK_GT(ret, 0);
+    }
 
+    BOOST_AUTO_TEST_CASE(dump_csv_ts) {     //
+        // Create parser
+        auto parser = new FTDCParser();
+
+        std::vector<std::string> fileList;
+        for (auto &&fileInPath: std::filesystem::directory_iterator(DATA_TEST_DIR))
+            fileList.push_back(fileInPath.path().string());
+
+        const std::string s =  "./output_ts.csv";
+        auto ret = parser->dumpDocsAsCsvTimestamps(fileList[0], s, INVALID_TIMESTAMP, INVALID_TIMESTAMP );
+
+        BOOST_CHECK_GT(ret, 0);
     }
 
 BOOST_AUTO_TEST_SUITE_END()
